@@ -8,7 +8,7 @@ phyclust.logL <- function(X, ret.phyclust = NULL,
     if(is.null(K) || is.null(Eta) || is.null(Mu) || is.null(Tt) ||
        is.null(substitution.model) ||
        is.null(identifier) || is.null(code.type)){
-      stop("Parameters are not specified correctly.")
+      stop("The parameters are not specified correctly.")
     } else{
       ret.phyclust <- list(K = K, Eta = Eta, Mu = Mu,
                            QA = list(pi = pi, kappa = kappa, Tt = Tt,
@@ -18,7 +18,7 @@ phyclust.logL <- function(X, ret.phyclust = NULL,
     }
   } else{
     if(class(ret.phyclust) != "phyclust"){
-      stop("ret.phyclust should be in a phyclust class.")
+      stop("The ret.phyclust should be in a phyclust class.")
     }
   }
 
