@@ -1,9 +1,8 @@
 /* This file contains a function R_Pt() called by R wraps Pt() in
-   "R/f_Pt.r", and this function calls the relative functions
-   in "src/phyclust_qmatrix.c".
-
-   Writen: Wei-Chen Chen on 2009/10/04.
-*/
+ * "R/f_Pt.r", and this function calls the relative functions
+ * in "src/phyclust_qmatrix.c".
+ *
+ * Writen: Wei-Chen Chen on 2009/10/04. */
 
 #include <R.h>
 #include <Rinternals.h>
@@ -13,15 +12,14 @@ Q_matrix* R_initialize_Q_matrix(int code_type, int substitution_model);
 void R_free_Q_matrix(Q_matrix *Q);
 
 /* This function calls functions in "src/phyclust_qmatrix.c" and is
-   called by Pt() using .Call() in "R/f_Pt.r".
-   Input:
-     R_pi: SEXP[1], equilibirium distribution, pi's.
-     R_kappa: SEXP[1], selection parameters, kappa.
-     R_Tt: SEXP[1], total evolved time.
-     R_substitution_mode: SEXP[1], index for substitution model.
-   Output:
-     ret: a list contains everythings returned from Update_log_Pt in C.
-*/
+ * called by Pt() using .Call() in "R/f_Pt.r".
+ * Input:
+ *   R_pi: SEXP[1], equilibirium distribution, pi's.
+ *   R_kappa: SEXP[1], selection parameters, kappa.
+ *   R_Tt: SEXP[1], total evolved time.
+ *   R_substitution_mode: SEXP[1], index for substitution model.
+ * Output:
+ *   ret: a list contains everythings returned from Update_log_Pt in C. */
 SEXP R_phyclust_logPt(SEXP R_pi, SEXP R_kappa, SEXP R_Tt,
 		SEXP R_code_type, SEXP R_substitution_model){
 	/* Declare variables for calling C. */
